@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2002-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -31,8 +31,8 @@
 #include "cmds.h"
 
 // kde includes
-#include <KLocalizedString>
-#include <KMessageBox>
+#include <klocale.h>
+#include <kmessagebox.h>
 
 // qt includes
 #include <QDrag>
@@ -43,7 +43,7 @@
 // system includes
 #include <cstdlib>
 
-#define DBG_LVI QLatin1String("UMLListViewItem")
+#define DBG_LVI "UMLListViewItem"
 
 DEBUG_REGISTER(UMLListViewItem)
 
@@ -189,6 +189,7 @@ UMLListViewItem::~UMLListViewItem()
 void UMLListViewItem::init()
 {
     m_type = lvt_Unknown;
+    m_bCreating = false;
     m_object = 0;
     m_id = Uml::ID::None;
 }
@@ -350,11 +351,19 @@ void UMLListViewItem::updateObject()
     Icon_Utils::IconType icon = Icon_Utils::it_Home;
     switch (ot) {
     case UMLObject::ot_Package:
-        if (m_object->stereotype() == QLatin1String("subsystem"))
+        if (m_object->stereotype() == "subsystem")
             icon = Icon_Utils::it_Subsystem;
         else
             icon = Icon_Utils::it_Package;
         break;
+        /*
+            case UMLObject::ot_Folder:
+                {
+                    ListViewType lvt = Model_Utils::convert_OT_LVT(m_object);
+                    icon = Model_Utils::convert_LVT_IT(lvt);
+                }
+                break;
+         */
     case UMLObject::ot_Operation:
         if (scope == Uml::Visibility::Public)
             icon = Icon_Utils::it_Public_Method;
@@ -382,10 +391,6 @@ void UMLListViewItem::updateObject()
         icon = Model_Utils::convert_LVT_IT(m_type);
         break;
 
-    case UMLObject::ot_Class:
-        icon = Model_Utils::convert_LVT_IT(m_type, m_object);
-        break;
-
     default:
         icon = Model_Utils::convert_LVT_IT(m_type);
         break;
@@ -399,8 +404,7 @@ void UMLListViewItem::updateObject()
  */
 void UMLListViewItem::updateFolder()
 {
-    Icon_Utils::IconType icon = Model_Utils::convert_LVT_IT(m_type, m_object);
-
+    Icon_Utils::IconType icon = Model_Utils::convert_LVT_IT(m_type);
     if (icon) {
         if (Model_Utils::typeIsFolder(m_type))
             icon = (Icon_Utils::IconType)((int)icon + (int)isExpanded());
@@ -443,6 +447,18 @@ QString UMLListViewItem::getSavedText() const
     return m_label;
 }
 
+/**
+ * Sets if the item is in the middle of being created.
+ */
+void UMLListViewItem::setCreating( bool creating )
+{
+    m_bCreating = creating;
+}
+
+bool UMLListViewItem::creating() const {
+    return m_bCreating;
+}
+
 /**
  * Set the pixmap corresponding to the given IconType.
  */
@@ -453,15 +469,34 @@ void UMLListViewItem::setIcon(Icon_Utils::IconType iconType)
 }
 
 /**
- * This slot is called to finish item editing
+ * Start the rename process.
  */
-void UMLListViewItem::slotEditFinished(const QString &newText)
+void UMLListViewItem::startRename(int col)
 {
-    m_label = text(0);
+    DEBUG(DBG_LVI) << this << " - column=" << col << ", text=" << text(col);
+    m_label = text(col);  // keep the old text
+}
 
-    DEBUG(DBG_LVI) << this << "text=" << newText;
+/**
+ * This function is called if the user presses Enter during in-place renaming
+ * of the item in column col.
+ */
+void UMLListViewItem::okRename(int col)
+{
+    DEBUG(DBG_LVI) << this << " - column=" << col << ", text=" << text(col);
     UMLListView* listView = static_cast<UMLListView*>(treeWidget());
     UMLDoc* doc = listView->document();
+    if (m_bCreating) {
+        m_bCreating = false;
+        if (listView->itemRenamed(this, col)) {
+//:TODO:            listView->ensureItemVisible(this);
+            doc->setModified(true);
+        } else {
+            delete this;
+        }
+        return;
+    }
+    QString newText = text(col);
     if (newText == m_label) {
         return;
     }
@@ -485,7 +520,6 @@ void UMLListViewItem::slotEditFinished(const QString &newText)
     case lvt_EnumLiteral:
     case lvt_Subsystem:
     case lvt_Component:
-    case lvt_Port:
     case lvt_Node:
     case lvt_Category:
         if (m_object == 0 || !doc->isUnique(newText)) {
@@ -686,6 +720,19 @@ void UMLListViewItem::cancelRenameWithMsg()
     setText(m_label);
 }
 
+/**
+ * Overrides default method to make public.
+ */
+void UMLListViewItem::cancelRename(int col)
+{
+    DEBUG(DBG_LVI) << this << " - column=" << col << ", text=" << text(col);
+    Q_UNUSED(col);
+    if (m_bCreating) {
+        UMLListView* listView = static_cast<UMLListView*>(treeWidget());
+        listView->cancelRename(this);
+    }
+}
+
 /**
  * Overrides the default sorting to sort by item type.
  * Sort the listview items by type and position within the corresponding list
@@ -863,19 +910,19 @@ UMLListViewItem * UMLListViewItem::findItem(Uml::ID::Type id)
  */
 void UMLListViewItem::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
-    QDomElement itemElement = qDoc.createElement(QLatin1String("listitem"));
+    QDomElement itemElement = qDoc.createElement("listitem");
     Uml::ID::Type id = ID();
     QString idStr = Uml::ID::toString(id);
     //DEBUG(DBG_LVI) << "id = " << idStr << ", type = " << m_type;
     if (id != Uml::ID::None)
-        itemElement.setAttribute(QLatin1String("id"), idStr);
-    itemElement.setAttribute(QLatin1String("type"), m_type);
+        itemElement.setAttribute("id", idStr);
+    itemElement.setAttribute("type", m_type);
     UMLFolder *extFolder = 0;
     if (m_object == 0) {
         if (! Model_Utils::typeIsDiagram(m_type) && m_type != lvt_View)
             uError() << text(0) << ": m_object is NULL";
         if (m_type != lvt_View)
-            itemElement.setAttribute(QLatin1String("label"), text(0));
+            itemElement.setAttribute("label", text(0));
     } else if (m_object->id() == Uml::ID::None) {
         if (text(0).isEmpty()) {
             DEBUG(DBG_LVI) << "Skipping empty item";
@@ -883,16 +930,16 @@ void UMLListViewItem::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
         }
         DEBUG(DBG_LVI) << "saving local label " << text(0) << " because umlobject ID is not set";
         if (m_type != lvt_View)
-            itemElement.setAttribute(QLatin1String("label"), text(0));
+            itemElement.setAttribute("label", text(0));
     } else if (m_object->baseType() == UMLObject::ot_Folder) {
         extFolder = static_cast<UMLFolder*>(m_object);
         if (!extFolder->folderFile().isEmpty()) {
-            itemElement.setAttribute(QLatin1String("open"), QLatin1String("0"));
+            itemElement.setAttribute("open", "0");
             qElement.appendChild(itemElement);
             return;
         }
     }
-    itemElement.setAttribute(QLatin1String("open"), isExpanded());
+    itemElement.setAttribute("open", isExpanded());
     QDomElement folderRoot;
     for (int i=0; i < childCount(); i++) {
         UMLListViewItem *childItem = static_cast<UMLListViewItem*>(child(i));
@@ -906,13 +953,13 @@ void UMLListViewItem::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
  */
 bool UMLListViewItem::loadFromXMI(QDomElement& qElement)
 {
-    QString id = qElement.attribute(QLatin1String("id"), QLatin1String("-1"));
-    QString type = qElement.attribute(QLatin1String("type"), QLatin1String("-1"));
-    QString label = qElement.attribute(QLatin1String("label"));
-    QString open = qElement.attribute(QLatin1String("open"), QLatin1String("1"));
+    QString id = qElement.attribute("id", "-1");
+    QString type = qElement.attribute("type", "-1");
+    QString label = qElement.attribute("label", "");
+    QString open = qElement.attribute("open", "1");
     if (!label.isEmpty())
         setText(label);
-    else if (id == QLatin1String("-1")) {
+    else if (id == "-1") {
         uError() << "Item of type " << type << " has neither ID nor label";
         return false;
     }
@@ -938,103 +985,99 @@ QString UMLListViewItem::toString(ListViewType type)
 {
     switch (type) {
         case lvt_View:
-            return QLatin1String("lvt_View");
+            return "lvt_View";
         case lvt_Logical_View:
-            return QLatin1String("lvt_Logical_View");
+            return "lvt_Logical_View";
         case lvt_UseCase_View:
-            return QLatin1String("lvt_UseCase_View");
+            return "lvt_UseCase_View";
         case lvt_Logical_Folder:
-            return QLatin1String("lvt_Logical_Folder");
+            return "lvt_Logical_Folder";
         case lvt_UseCase_Folder:
-            return QLatin1String("lvt_UseCase_Folder");
+            return "lvt_UseCase_Folder";
         case lvt_UseCase_Diagram:
-            return QLatin1String("lvt_UseCase_Diagram");
+            return "lvt_UseCase_Diagram";
         case lvt_Collaboration_Diagram:
-            return QLatin1String("lvt_Collaboration_Diagram");
+            return "lvt_Collaboration_Diagram";
         case lvt_Class_Diagram:
-            return QLatin1String("lvt_Class_Diagram");
+            return "lvt_Class_Diagram";
         case lvt_State_Diagram:
-            return QLatin1String("lvt_State_Diagram");
+            return "lvt_State_Diagram";
         case lvt_Activity_Diagram:
-            return QLatin1String("lvt_Activity_Diagram");
+            return "lvt_Activity_Diagram";
         case lvt_Sequence_Diagram:
-            return QLatin1String("lvt_Sequence_Diagram");
+            return "lvt_Sequence_Diagram";
         case lvt_Actor:
-            return QLatin1String("lvt_Actor");
+            return "lvt_Actor";
         case lvt_UseCase:
-            return QLatin1String("lvt_UseCase");
+            return "lvt_UseCase";
         case lvt_Class:
-            return QLatin1String("lvt_Class");
+            return "lvt_Class";
         case lvt_Attribute:
-            return QLatin1String("lvt_Attribute");
+            return "lvt_Attribute";
         case lvt_Operation:
-            return QLatin1String("lvt_Operation");
+            return "lvt_Operation";
         case lvt_Template:
-            return QLatin1String("lvt_Template");
+            return "lvt_Template";
         case lvt_Interface:
-            return QLatin1String("lvt_Interface");
+            return "lvt_Interface";
         case lvt_Package:
-            return QLatin1String("lvt_Package");
+            return "lvt_Package";
         case lvt_Component_Diagram:
-            return QLatin1String("lvt_Component_Diagram");
+            return "lvt_Component_Diagram";
         case lvt_Component_Folder:
-            return QLatin1String("lvt_Component_Folder");
+            return "lvt_Component_Folder";
         case lvt_Component_View:
-            return QLatin1String("lvt_Component_View");
+            return "lvt_Component_View";
         case lvt_Component:
-            return QLatin1String("lvt_Component");
+            return "lvt_Component";
         case lvt_Diagrams:
-            return QLatin1String("lvt_Diagrams");
+            return "lvt_Diagrams";
         case lvt_Artifact:
-            return QLatin1String("lvt_Artifact");
+            return "lvt_Artifact";
         case lvt_Deployment_Diagram:
-            return QLatin1String("lvt_Deployment_Diagram");
+            return "lvt_Deployment_Diagram";
         case lvt_Deployment_Folder:
-            return QLatin1String("lvt_Deployment_Folder");
+            return "lvt_Deployment_Folder";
         case lvt_Deployment_View:
-            return QLatin1String("lvt_Deployment_View");
-        case lvt_Port:
-            return QLatin1String("lvt_Port");
+            return "lvt_Deployment_View";
         case lvt_Node:
-            return QLatin1String("lvt_Node");
+            return "lvt_Node";
         case lvt_Datatype:
-            return QLatin1String("lvt_Datatype");
+            return "lvt_Datatype";
         case lvt_Datatype_Folder:
-            return QLatin1String("lvt_Datatype_Folder");
+            return "lvt_Datatype_Folder";
         case lvt_Enum:
-            return QLatin1String("lvt_Enum");
+            return "lvt_Enum";
         case lvt_Entity:
-            return QLatin1String("lvt_Entity");
+            return "lvt_Entity";
         case lvt_EntityAttribute:
-            return QLatin1String("lvt_EntityAttribute");
+            return "lvt_EntityAttribute";
         case lvt_EntityRelationship_Diagram:
-            return QLatin1String("lvt_EntityRelationship_Diagram");
+            return "lvt_EntityRelationship_Diagram";
         case lvt_EntityRelationship_Folder:
-            return QLatin1String("lvt_EntityRelationship_Folder");
+            return "lvt_EntityRelationship_Folder";
         case lvt_EntityRelationship_Model:
-            return QLatin1String("lvt_EntityRelationship_Model");
+            return "lvt_EntityRelationship_Model";
         case lvt_Subsystem:
-            return QLatin1String("lvt_Subsystem");
+            return "lvt_Subsystem";
         case lvt_Model:
-            return QLatin1String("lvt_Model");
+            return "lvt_Model";
         case lvt_EnumLiteral:
-            return QLatin1String("lvt_EnumLiteral");
+            return "lvt_EnumLiteral";
         case lvt_UniqueConstraint:
-            return QLatin1String("lvt_UniqueConstraint");
+            return "lvt_UniqueConstraint";
         case lvt_PrimaryKeyConstraint:
-            return QLatin1String("lvt_PrimaryKeyConstraint");
+            return "lvt_PrimaryKeyConstraint";
         case lvt_ForeignKeyConstraint:
-            return QLatin1String("lvt_ForeignKeyConstraint");
+            return "lvt_ForeignKeyConstraint";
         case lvt_CheckConstraint:
-            return QLatin1String("lvt_CheckConstraint");
+            return "lvt_CheckConstraint";
         case lvt_Category:
-            return QLatin1String("lvt_Category");
-        case lvt_Properties:
-            return QLatin1String("lvt_Properties");
+            return "lvt_Category";
         case lvt_Unknown:
-            return QLatin1String("lvt_Unknown");
+            return "lvt_Unknown";
         default:
-            return QLatin1String("? ListViewType ?");
+            return "? ListViewType ?";
     }
 }
 
